.. Translate Python documentation master file, created by
   sphinx-quickstart on Wed Nov 29 06:50:23 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Translate Python's documentation!
============================================

Translate is a simple but powerful translation tool written in python with with support for multiple translation providers. By now we are integrated with Microsoft Translation API and Translated MyMemory API



Quickstart
----------

.. toctree::
    :maxdepth: 1

    quickstart/installation.rst


User Guide
----------

.. toctree::
    :maxdepth: 1

    overview.rst
    providers.rst
    tutorial.rst


Development
-----------

.. toctree::
    :maxdepth: 1

    development/installation.rst
    development/release.rst


Other
-----

.. toctree::
    :maxdepth: 2

    changelog.rst

Downloads
---------

- `PDF <https://readthedocs.org/projects/translate-python/downloads/pdf/latest/>`_

- `Epub <https://readthedocs.org/projects/translate-python/downloads/epub/latest/>`_
